// Wait for DOM to fully load
document.addEventListener('DOMContentLoaded', () => {
    animateElementsOnLoad();
    initializeSidebar();
    initializeViewToggles();
    setupDismissButton();
    setupFileUpload();
    setupAddSiteButton();
    setupFilterButtons();
    setupSearchFunctionality();
    addDynamicStyles();
    initializeNavigation();
    setupTerminal();
    setupPhpConfig();
    setupVisibility();
    setupSettings();
    setupExtensions();
    setupDomains();
    setupBilling();
});

// Animate elements when page loads
function animateElementsOnLoad() {
    const siteItems = document.querySelectorAll('.site-item, .domain-item, .extension-item, .billing-item');
    siteItems.forEach((item, index) => {
        item.style.opacity = '0';
        item.style.transform = 'translateY(20px)';
        setTimeout(() => {
            item.style.transition = 'opacity 0.5s ease, transform 0.5s ease';
            item.style.opacity = '1';
            item.style.transform = 'translateY(0)';
        }, 100 + (index * 100));
    });

    const sections = document.querySelectorAll('.view-transition');
    sections.forEach((section, index) => {
        section.classList.add('hidden');
        setTimeout(() => {
            section.classList.remove('hidden');
        }, 300 + (index * 150));
    });
}

// Initialize sidebar functionality
function initializeSidebar() {
    const sidebarToggle = document.getElementById('sidebarToggle');
    const sidebar = document.querySelector('.sidebar');

    if (sidebarToggle) {
        sidebarToggle.addEventListener('click', () => {
            sidebar.classList.toggle('collapsed');
            const icon = sidebarToggle.querySelector('i');
            icon.style.transition = 'transform 0.3s ease';
            if (sidebar.classList.contains('collapsed')) {
                icon.classList.remove('fa-angles-left');
                icon.classList.add('fa-angles-right');
                icon.style.transform = 'rotate(180deg)';
            } else {
                icon.classList.remove('fa-angles-right');
                icon.classList.add('fa-angles-left');
                icon.style.transform = 'rotate(0)';
            }
        });
    }

    const sidebarItems = document.querySelectorAll('.sidebar-nav li a');
    sidebarItems.forEach(item => {
        item.addEventListener('mouseenter', () => {
            if (!item.parentElement.classList.contains('active')) {
                item.style.transition = 'all 0.2s ease';
                item.style.paddingLeft = '20px';
            }
        });
        item.addEventListener('mouseleave', () => {
            if (!item.parentElement.classList.contains('active')) {
                item.style.paddingLeft = '15px';
            }
        });
    });

    function handleResize() {
        if (window.innerWidth < 992 && !sidebar.classList.contains('collapsed')) {
            sidebar.classList.add('collapsed');
            const icon = sidebarToggle.querySelector('i');
            icon.classList.remove('fa-angles-left');
            icon.classList.add('fa-angles-right');
        }
    }

    handleResize();
    window.addEventListener('resize', handleResize);

    // Sub-menu toggle
    const projectToggle = document.querySelector('.project-manager-toggle');
    const subMenu = document.querySelector('.sub-menu');
    const subMenuToggle = document.querySelector('.sub-menu-toggle');

    if (projectToggle && subMenu && subMenuToggle) {
        projectToggle.addEventListener('click', (e) => {
            if (e.target === subMenuToggle || e.target.closest('.sub-menu-toggle')) {
                subMenu.classList.toggle('active');
                subMenuToggle.classList.toggle('active');
            }
        });
    }
}

// Initialize navigation for section switching
function initializeNavigation() {
    const navLinks = document.querySelectorAll('.sidebar-nav a');
    const contentSections = document.querySelectorAll('.content-section');
    const mainTitle = document.getElementById('main-title');

    navLinks.forEach(link => {
        link.addEventListener('click', (e) => {
            const href = link.getAttribute('href');
            if (href.startsWith('#')) {
                e.preventDefault();
                const targetId = href.substring(1);

                // Update active nav item
                navLinks.forEach(l => l.parentElement.classList.remove('active'));
                link.parentElement.classList.add('active');

                // Show target section
                contentSections.forEach(section => {
                    section.classList.remove('active');
                    if (section.id === targetId) {
                        section.classList.add('active');
                        if (mainTitle) {
                            mainTitle.textContent = link.querySelector('span')?.textContent || targetId.replace(/-/g, ' ').toUpperCase();
                        }
                    }
                });

                // Animate section content
                const sectionContent = document.querySelector(`#${targetId} .view-transition`);
                if (sectionContent) {
                    sectionContent.classList.add('hidden');
                    setTimeout(() => {
                        sectionContent.classList.remove('hidden');
                    }, 10);
                }
            }
        });
    });

    // Set initial active section based on URL hash
    const hash = window.location.hash.substring(1);
    if (hash) {
        const targetSection = document.getElementById(hash);
        if (targetSection) {
            contentSections.forEach(section => section.classList.remove('active'));
            targetSection.classList.add('active');
            const activeLink = document.querySelector(`.sidebar-nav a[href="#${hash}"]`);
            if (activeLink) {
                navLinks.forEach(l => l.parentElement.classList.remove('active'));
                activeLink.parentElement.classList.add('active');
                if (mainTitle) {
                    mainTitle.textContent = activeLink.querySelector('span')?.textContent || hash.replace(/-/g, ' ').toUpperCase();
                }
            }
        }
    }
}

// Setup terminal functionality
function setupTerminal() {
    const terminalOutput = document.querySelector('.terminal-output');
    const clearButton = document.querySelector('.clear-terminal');

    if (terminalOutput && clearButton) {
        terminalOutput.addEventListener('keydown', (e) => {
            if (e.key === 'Enter') {
                e.preventDefault();
                const command = terminalOutput.textContent.trim().split('\n').pop().replace('$ ', '');
                terminalOutput.innerHTML += `<p>$ ${command}</p>`;
                if (command === 'help') {
                    terminalOutput.innerHTML += `<p>Available commands: ls, cd, deploy, status</p>`;
                } else {
                    terminalOutput.innerHTML += `<p>Command not recognized: ${command}</p>`;
                }
                terminalOutput.scrollTop = terminalOutput.scrollHeight;
            }
        });

        clearButton.addEventListener('click', () => {
            terminalOutput.innerHTML = `<p>$ Welcome to Orbizen Cloud Terminal</p><p>Type 'help' for available commands</p>`;
        });
    }
}

// Setup PHP configuration
function setupPhpConfig() {
    const saveButton = document.querySelector('#php-config .save-button');
    if (saveButton) {
        saveButton.addEventListener('click', () => {
            const phpVersion = document.querySelector('#php-config select').value;
            const extensions = Array.from(document.querySelectorAll('#php-config input:checked')).map(input => input.parentElement.textContent.trim());
            console.log('Saving PHP Config:', { phpVersion, extensions });
            showSaveFeedback(saveButton);
        });
    }
}

// Setup visibility
function setupVisibility() {
    const saveButton = document.querySelector('#visibility .save-button');
    if (saveButton) {
        saveButton.addEventListener('click', () => {
            const visibility = document.querySelector('#visibility input:checked').value;
            console.log('Saving Visibility:', visibility);
            showSaveFeedback(saveButton);
        });
    }
}

// Setup other settings
function setupSettings() {
    const saveButton = document.querySelector('#other-settings .save-button');
    if (saveButton) {
        saveButton.addEventListener('click', () => {
            const envVars = document.querySelector('#other-settings textarea').value;
            console.log('Saving Environment Variables:', envVars);
            showSaveFeedback(saveButton);
        });
    }
}

// Setup extensions
function setupExtensions() {
    const installButtons = document.querySelectorAll('.extension-item .action-button');
    installButtons.forEach(button => {
        button.addEventListener('click', () => {
            const extensionName = button.parentElement.querySelector('h3').textContent;
            console.log(`Installing extension: ${extensionName}`);
            showSaveFeedback(button);
        });
    });
}

// Setup domains
function setupDomains() {
    const actionButtons = document.querySelectorAll('.domain-item .action-button');
    actionButtons.forEach(button => {
        button.addEventListener('click', () => {
            const action = button.textContent;
            const domain = button.closest('.domain-item').querySelector('h3').textContent;
            console.log(`${action} for domain: ${domain}`);
            showSaveFeedback(button);
        });
    });
}

// Setup billing
function setupBilling() {
    const upgradeButton = document.querySelector('#billing .upgrade-button');
    if (upgradeButton) {
        upgradeButton.addEventListener('click', () => {
            console.log('Upgrading plan');
            showSaveFeedback(upgradeButton);
        });
    }
}

// Show save feedback
function showSaveFeedback(button) {
    const feedback = document.createElement('span');
    feedback.textContent = 'Saved!';
    feedback.style.marginLeft = '10px';
    feedback.style.color = 'var(--success-color)';
    feedback.style.opacity = '0';
    button.parentElement.appendChild(feedback);

    setTimeout(() => {
        feedback.style.transition = 'opacity 0.3s ease';
        feedback.style.opacity = '1';
    }, 10);

    setTimeout(() => {
        feedback.style.opacity = '0';
        setTimeout(() => feedback.remove(), 300);
    }, 2000);
}

// Existing functions (initializeViewToggles, setupDismissButton, etc.) remain unchanged
// Add grid layout support for project list
function initializeViewToggles() {
    const listViewButton = document.querySelector('.list-view');
    const gridViewButton = document.querySelector('.grid-view');
    const sitesList = document.querySelector('.sites-list');

    if (listViewButton && gridViewButton && sitesList) {
        listViewButton.addEventListener('click', () => {
            addTransitionToSites();
            listViewButton.classList.add('active');
            gridViewButton.classList.remove('active');
            sitesList.classList.remove('grid-layout');
        });

        gridViewButton.addEventListener('click', () => {
            addTransitionToSites();
            gridViewButton.classList.add('active');
            listViewButton.classList.remove('active');
            sitesList.classList.add('grid-layout');
        });
    }

    function addTransitionToSites() {
        const sites = document.querySelectorAll('.site-item');
        sites.forEach(site => {
            site.style.transition = 'all 0.3s cubic-bezier(0.4, 0, 0.2, 1)';
        });
    }
}